Credits & License
=================

Citing Brightway
----------------

Brightway has been published in the `Journal of Open Source Software <http://joss.theoj.org/papers/6c24869ed7f1e66b3b837c31579c6fe5>`__. You can find a bibtex reference in the journal, or use the following cite:

Mutel, C. 2017. Brightway: An open source framework for Life Cycle Assessment. Journal of Open Source Software, 12:2. https://doi.org/10.21105%2Fjoss.00236.

.. _authors:

Authors
-------

* `Chris Mutel <http://chris.mutel.org/>`__
* `Adrian Haas <https://www.ethz.ch/content/specialinterest/baug/institute-ifu/institute-ifu/en/das-institut/personen/personen-detail.html?persid=171851>`__
* `Giuseppe Cardellini <http://www.kuleuven.be/wieiswie/en/person/90387>`__
* `Andreas Froemelt <http://www.ifu.ethz.ch/ESD/people/andrefro>`__
* `Niko Heeren <http://www.ifu.ethz.ch/staff/nheeren/index_EN>`__
* `Aurelian Jaggi <http://eaternity.ch/team/Aurelian-Jaggi/>`__
* `Maghimai Marcus <https://www.researchgate.net/profile/Maghimai_Marcus2>`__
* `Marie de Saxcé <http://lca-net.com/about/who-we-are/>`__
* `Low Kian Seong <https://bitbucket.org/lowks>`__
* `Bernhard Steubing <http://www.ifu.ethz.ch/ESD/people/bsteubin>`__
* `Pascal Lesage <http://www.polymtl.ca/recherche/rc/en/professeurs/details.php?NoProf=551>`__
* `Manuel Klarmann <https://twitter.com/mklarmann>`__
* `Tomas Navarrete <https://www.linkedin.com/in/tom4m3>`__
* Guillaume Audard

Logo by `eightz <http://www.fiverr.com/ei8htz>`__.

Acknowledgements
----------------

Brightway2 would not be possible without the incredibly generous support of `Professor Stefanie Hellweg <http://www.ifu.ethz.ch/staff/hellwegs>`_ of ETH Zürich. Brightway2 was (indirectly) funded by the people of Switzerland.

.. _contact-developers:

Contact the developers
----------------------

.. note:: Please subscribe to the `brightway2 updates mailing list <https://tinyletter.com/brightway2-updates>`_ to be informed of new releases.

Brightway2 has a mailing list: brightway2@googlegroups.com. You can register at the `Google groups site <https://groups.google.com/forum/?fromgroups#!forum/brightway2>`_.

You can also email Chris directly at ``cmutel@gmail.com``.

License
-------

Brightway2 is licensed under the `BSD license <http://opensource.org/licenses/BSD-3-Clause>`_.

::

    Copyright (c) 2016, Chris Mutel and ETH Zürich
    All rights reserved.

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:

    Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer. Redistributions in binary
    form must reproduce the above copyright notice, this list of conditions and the
    following disclaimer in the documentation and/or other materials provided
    with the distribution.

    Neither the name of ETH Zürich nor the names of its contributors may be used
    to endorse or promote products derived from this software without specific
    prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
